/**
 * Module dependencies.
 */

var express = require('express')
    , http = require('http')
    , path = require('path')
    , fs = require("fs")
    , _ = require('underscore')
    , logger = require('morgan')
    , bodyParser = require('body-parser')
    , cookieSession = require('cookie-session')
    , methodOverride = require('method-override')
    , static = require('serve-static')
    , favicon = require('serve-favicon')
    , errorHandler = require('errorhandler')
    , cookieParser = require('cookie-parser');
//var upload = require('blueimp-file-upload-expressjs-node-v4');
var app = module.exports = express();

// commandline option
// multiuser mode
var isMultiuser = (_.indexOf(process.argv, "multiuser") !== -1)? true: false;
var isAllowRemote = (_.indexOf(process.argv, "allowremote") !== -1)? true: false;
app.set('isMultiuser', isMultiuser);
app.set('isAllowRemote', isAllowRemote);
var routes = require('./routes');
routes.file = require('./routes/file.js');

// all environments
app.set('port', process.env.PORT || 3000);
app.set('views', __dirname + '/views');
app.set('view engine', 'pug');

// upload.configure();

var logStream;
process.umask(0);
if(isMultiuser){
    logStream = fs.createWriteStream('userdata/access_log.multiuser', {flags: 'a'});
} else{
    logStream = fs.createWriteStream('userdata/access_log.singleuser', {flags: 'a'});
}
app.use(logger("combined",{stream: logStream}));
// app.use('/file/:type', upload.fileHandler());

app.use(bodyParser.json({limit: '1mb'}));
app.use(bodyParser.urlencoded({extended:true, limit:'1mb', parameterLimit: 10000}));
app.use(methodOverride());

// access restriction
app.use(function(req, res, next){
    var hostname = req.headers.host;
    hostname = hostname.split(":")[0];
    if(hostname  === null || hostname === undefined){
        res.sendStatus(400);
        return;
    }
    // if the request is from localhost, accept.
    if(hostname === "localhost" || hostname === "127.0.0.1"){
        next();
        return;
    }
    // if the "isAllowRemote" is true or multiuser mode, accept remote access.
    else if(isAllowRemote || isMultiuser){
        next();
        return;
    }
    // if the remote access is not allowed, respond 400.
    else{
        res.sendStatus(400);
    }
});

app.put('/file/object/:name', routes.file.saveNetwork);
app.put('/file/object/sheet/:name', routes.file.saveNetworkPerSheet);
app.post('/file/:type/:name',   routes.file.addFile);
app.post('/file/:type/:name/:size',   routes.file.addFile);
app.post('/package/:name', routes.file.addPackage);
app.delete('/package/:pkgname', routes.file.delPackage);
app.get('/package', routes.file.existingPackage);

app.use(express.Router());
app.use(static(path.join(__dirname, 'public')));
app.use(favicon(path.join(__dirname, 'public/favicon.ico')));
app.set("dirname", __dirname);
console.log(__dirname);

// development only
if ('development' == app.get('env')) {
    app.use(errorHandler());
}

app.get('/', routes.index);
app.get('/keepalive', routes.keepalive);
app.get('/def/:name', routes.nodedefs);
app.get('/preference/:file', routes.preference);
app.put('/preference/:file', routes.preferenceSet);

app.get('/file/:name', routes.file.getFile);
app.delete('/file/:name', routes.file.deleteFile);
app.get("/filelist", routes.file.getAllFiles);
app.get("/dirlist", routes.file.getDir);
app.post("/dirlist/set_dir", routes.file.setDir);
app.get("/dl/:type/:name", routes.file.dlFile);
app.get("/datapath", routes.file.datapath);
app.get('/filename/', routes.file.getFilenames);

app.get("/execution/:file", routes.execution);
app.get("/abort", routes.abort);
app.get("/execstatus", routes.execstatus);

app.get("/packagelist", routes.packagelist);

if(isMultiuser){
    app.post("/login/:type", routes.multiuser.checklogin);
    app.get("/login", routes.multiuser.login);
    app.get("/logout", routes.multiuser.logout);
    app.get("/admin", routes.multiuser.admin);
    app.get("/admin/userlist", routes.multiuser.allusers);
    app.delete("/admin/user/:name", routes.multiuser.deluser);
    app.post("/admin/user/:name", routes.multiuser.updateuser);
}

app.get("/os", routes.os);
app.put('/reshapedNodes', routes.reshape);

app.set('getRoot', routes.file.getRoot);

http.createServer(app).listen(app.get('port'), function(){
    console.log('Express server listening on port ' + app.get('port'));
});
