var async = require('async');
module.exports = {
    '@tags': ['pd_environment'],

    before: function (client) {
        client
            .url('http://localhost:3000')
            .waitForElementVisible('#topmenu', 1000);
    },

    after: function (client) {
        client.end();
    },

    /**
     * Test: 5-001
     * Expects:
     *  - Preferences dialog will appear with 6 buttons
     */
    '5-001': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@preferenceDialog').to.be.visible;
                callback();
            },
            function (callback) {
                // 5-001
                preferenceTest.expect.element('@packagesBtn').to.be.visible;
                preferenceTest.expect.element('@displayBtn').to.be.visible;
                preferenceTest.expect.element('@versionBtn').to.be.visible;
                preferenceTest.expect.element('@resetBtn').to.be.visible;
                preferenceTest.expect.element('@tutorialBtn').to.be.visible;
                preferenceTest.expect.element('@environmentBtn').to.be.visible;
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 5-002
     * Expects:
     *  - Environment tab will be displayed.
     */
    '5-002': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.clickEnvironmentBtn(function () {
                    callback();
                })
            },
            function (callback) {
                client.pause(2000);
                // 5-002
                preferenceTest.expect.element('@addEnvironmentBtn').to.be.visible;
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 5-003
     * Expects:
     *  - There should be TEST1 and 123aaa in the variable name and value displayed respectively.
     */
    '5-003': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.click('@addEnvironmentBtn');
                callback();
            },
            function (callback) {
                preferenceTest.setValue('@variableNameInput', "TEST1");
                callback();
            },
            function (callback) {
                preferenceTest.setValue('@variableValueInput', "123aaa");
                callback();
            },
            function (callback) {
                preferenceTest.click('@applyEnvVariable');
                callback();
            },
            function (callback) {
                client.keys([client.Keys.ESCAPE]);
                callback();
            },
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.clickEnvironmentBtn(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.expect.element('@variableNameInput').to.have.value.that.equals('TEST1');
                preferenceTest.expect.element('@variableValueInput').to.have.value.that.equals('123aaa');
                callback();
            }
        ], function (err, stdout) {

        });

        client.end();
    }
}

